import * as t from 'drizzle-orm/pg-core';
import { timestamps } from '../util';
import { relations } from 'drizzle-orm';
import { users } from './users';
import { schedulingModes } from './schedulingmodes';
import { matches } from './matches';
import { breakperiods } from './breakperiods';
import { fields } from './fields';
import { teams } from './teams';

export const competitions = t.pgTable('competitions', {
	id: t.serial('id').primaryKey(),
	name: t.text('name').notNull(),
	description: t.text('description'),
	start_date: t.timestamp({ withTimezone: true, mode: 'date' }).notNull(),
	location: t.text('location'),
	current_scheduling_mode_id: t.integer('current_scheduling_mode_id').notNull(),
	owner: t.text('owner').notNull(),
	...timestamps
});

export const competitionsRelations = relations(competitions, ({ one, many }) => ({
	scheduling_modes: many(schedulingModes),
	owner: one(users, {
		fields: [competitions.owner],
		references: [users.id]
	}),
	matches: many(matches),
	breakperiods: many(breakperiods),
	fields: many(fields),
	teams: many(teams)
}));

export type Competition = typeof competitions.$inferSelect;
